import React from 'react';
import PropTypes from 'prop-types';

import ColumnFilter from './ColumnFilter';

const HeaderColumn = ({ columnMetaData, onClickSort, getSortIcon, onFilterChange, getFilterValue }) => {
  if (!columnMetaData.disableFilter) {
    return (
      <div className={`header-column cell__${columnMetaData.key}`}>
        <div
          title={columnMetaData.label}
          className="table-heading"
          onClick={e => onClickSort(columnMetaData.key, columnMetaData.disableFilter, e)}
          id={columnMetaData.key}
        >{getSortIcon(columnMetaData.key)}{columnMetaData.label}
        </div>
        <ColumnFilter
          selectedColumn={columnMetaData.key}
          onChange={onFilterChange}
          value={getFilterValue(columnMetaData.key)}
          key={columnMetaData.key}
        />
      </div>
    );
  }

  return (
    <div className={`header-column cell__${columnMetaData.key}`}>
      <div
        title={columnMetaData.label}
        className="table-heading"
        onClick={e => onClickSort(columnMetaData.key, e)}
        id={columnMetaData.key}
      >{getSortIcon()}{columnMetaData.label}
      </div>
    </div>
  );

};

HeaderColumn.propTypes = {
  columnMetaData: PropTypes.object,
  onFilterChange: PropTypes.func.isRequired,
  onClickSort: PropTypes.func.isRequired,
  getSortIcon: PropTypes.func.isRequired,
  getFilterValue: PropTypes.func.isRequired,
};

HeaderColumn.defaultProps = {
  columnMetaData: {},
};

export default HeaderColumn;
