import React, { Component } from 'react';
import PropTypes from 'prop-types';

import RowCell from './RowCell';
import '../.././datagrid.css';
/*
* The Row component for the grid which will render - RenderRow.
* @type {class}
*/
class Row extends Component {
  constructor(props) {
    super(props);
    this.renderRows = this.renderRows.bind(this);
  }
  renderRows({ data, currentMetaData, styles }) {
    return (
      <div className="table-row" style={styles.gridTableRow}>
        {currentMetaData.headerConfig.map((columnMetaData) => {
        if (columnMetaData.customComponent) {
          const CustomComponent = columnMetaData.customComponent;
          return (
            <RowCell
              isCustomComponent
              styles={styles}
              key={columnMetaData.key}
              cellId={columnMetaData.key}
            >
              <CustomComponent rowData={data} />
            </RowCell>
          );
        }
        return (
          <RowCell
            styles={styles}
            key={columnMetaData.key}
            cellId={columnMetaData.key}
            title={data[columnMetaData.key]}
          >
            {data[columnMetaData.key]}
          </RowCell>
        );
      })}
      </div>
    );
  }

  render() {
    const { data, currentMetaData, styles } = this.props;
    return (
      <div className="table-body-row">
        {this.renderRows({ data, currentMetaData, styles })}
      </div>
    );
  }
}

Row.propTypes = {
  data: PropTypes.object,
  currentMetaData: PropTypes.object,
  styles: PropTypes.object,
};

Row.defaultProps = {
  data: [],
  currentMetaData: {},
  styles: {},
};

export default Row;
