import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cloneDeep from 'lodash/cloneDeep';
import isEmpty from 'lodash/isEmpty';
import isEqual from 'lodash/isEqual';
import { getNoOfPages, addUniqueKey } from './utils/CommonUtils';
import './datagrid.css';
import DataGridSection from './components/dataGrid/DataGrid';

/*
 The DataGrid component for the grid which will render - DataGridSection.
 @type {class}
*/
const formattedData = (data, columnsConfig) => {
  const allkeys = columnsConfig.map((columnConfig) => {
    const obj = { key: columnConfig.key, type: columnConfig.type };
    return obj;
  });
  return data.map((dataObj) => {
    const dataObjCopy = cloneDeep(dataObj);
    allkeys.forEach((obj) => {
      if (dataObjCopy[obj.key] === undefined) {
        dataObjCopy[obj.key] = '';
      }
      if (obj.type === 'Number' && dataObjCopy[obj.key].trim().length !== 0 && !isEmpty(dataObjCopy[obj.key]) && !isNaN(dataObjCopy[obj.key])) {
        dataObjCopy[obj.key] = parseInt(dataObjCopy[obj.key]);
      }
    });
    return dataObjCopy;
  });
};

class DataGrid extends Component {
  constructor(props) {
    super(props);
    this.state = {
      data: addUniqueKey(props.data),
      metaData: props.metaData,
      styles: props.styles,
      indexOfLastRecord: props.metaData.recordsPerPage - 1,
      indexOfFirstRecord: 0,
      noOfPages: getNoOfPages(props.data, props.metaData.recordsPerPage),
    };
  }
  componentWillReceiveProps(nextProps) {
    if (!isEqual(nextProps.data, this.props.data)) {
      this.setState({
        data: addUniqueKey(this.props.data),
        metaData: this.props.metaData,
        styles: this.props.styles,
        indexOfLastRecord: this.props.metaData.recordsPerPage - 1,
        indexOfFirstRecord: 0,
        noOfPages: getNoOfPages(this.props.data, this.props.metaData.recordsPerPage),
      });
    }
  }
  render() {
    const tempData = formattedData(this.props.data, this.props.metaData.headerConfig);
    return (
      <DataGridSection
        data={tempData}
        metaData={this.props.metaData}
        styles={this.props.styles}
      />
    );
  }
}

DataGrid.propTypes = {
  data: PropTypes.array,
  metaData: PropTypes.object,
  styles: PropTypes.object,
};

DataGrid.defaultProps = {
  data: [],
  metaData: {},
  styles: {},
};

export default DataGrid;
